@@ -37,7 +37,7 @@
 #include <gdk/gdkx.h>
 
 #ifdef HAVE_DPMS_EXTENSION
-#include <X11/Xproto.h>			/* for CARD16 */
+#include <X11/Xproto.h>
 #include <X11/extensions/dpms.h>
 #include <X11/extensions/dpmsstr.h>
 #endif
@@ -53,10 +53,14 @@ static void     gpm_dpms_finalize   (GObject      *object);
 
 #define GPM_DPMS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_DPMS, GpmDpmsPrivate))
 
+/* until we get a nice event-emitting DPMS extension, we have to poll... */
+#define GPM_DPMS_POLL_TIME	10*1000
+
 struct GpmDpmsPrivate
 {
 	gboolean		 enabled;
 	gboolean		 active;
+	gboolean		 dpms_capable;
 
 	guint			 standby_timeout;
 	guint			 suspend_timeout;
@@ -117,9 +121,6 @@ x11_sync_server_dpms_settings (Display *dpy,
 			       GError **error)
 {
 #ifdef HAVE_DPMS_EXTENSION
-
-	int	 event = 0;
-	int      err = 0;
 	BOOL	 o_enabled = FALSE;
 	CARD16	 o_power = 0;
 	CARD16	 o_standby = 0;
@@ -129,25 +130,6 @@ x11_sync_server_dpms_settings (Display *dpy,
 	gpm_debug ("Syncing DPMS settings enabled=%d timeouts=%d %d %d",
 		   enabled, standby_secs, suspend_secs, off_secs);
 
-	if (! DPMSQueryExtension (dpy, &event, &err)) {
-		gpm_debug ("XDPMS extension not supported");
-		g_set_error (error,
-			     GPM_DPMS_ERROR,
-			     GPM_DPMS_ERROR_GENERAL,
-			     "DPMS extension not supported");
-		return FALSE;
-	}
-
-	if (! DPMSCapable (dpy)) {
-		gpm_debug ("Display is not DPMS capable");
-		g_set_error (error,
-			     GPM_DPMS_ERROR,
-			     GPM_DPMS_ERROR_GENERAL,
-			     "Display is not DPMS capable");
-
-		return FALSE;
-	}
-
 	if (! DPMSInfo (dpy, &o_power, &o_enabled)) {
 		gpm_debug ("unable to get DPMS state.");
 		g_set_error (error,
@@ -223,19 +205,12 @@ x11_get_mode (GpmDpms     *dpms,
 	      GError     **error)
 {
 	GpmDpmsMode result;
-	int	    event_number;
-	int	    error_number;
-	BOOL	    enabled = FALSE;
-	CARD16	    state;
+	BOOL enabled = FALSE;
+	CARD16 state;
 
-	if (! DPMSQueryExtension (GDK_DISPLAY (), &event_number, &error_number)) {
-		/* Server doesn't know -- assume the monitor is on. */
+	if (dpms->priv->dpms_capable == FALSE) {
+		/* Server or monitor can't DPMS -- assume the monitor is on. */
 		result = GPM_DPMS_MODE_ON;
-
-	} else if (! DPMSCapable (GDK_DISPLAY ())) {
-		/* Server says the monitor doesn't do power management -- so it's on. */
-		result = GPM_DPMS_MODE_ON;
-
 	} else {
 		DPMSInfo (GDK_DISPLAY (), &state, &enabled);
 		if (! enabled) {
@@ -275,22 +250,11 @@ x11_set_mode (GpmDpms	 *dpms,
 	      GError    **error)
 {
 	GpmDpmsMode current_mode;
-	CARD16	    state;
-	CARD16	    current_state;
-	BOOL	    current_enabled;
-	int	    event_number;
-	int	    error_number;
+	CARD16 state;
+	CARD16 current_state;
+	BOOL current_enabled;
 
-	if (! DPMSQueryExtension (GDK_DISPLAY (), &event_number, &error_number)) {
-		gpm_debug ("unable to query DPMS extention");
-		g_set_error (error,
-			     GPM_DPMS_ERROR,
-			     GPM_DPMS_ERROR_GENERAL,
-			     "DPMS extension not supported");
-		return FALSE;
-	}
-
-	if (! DPMSCapable (GDK_DISPLAY ())) {
+	if (dpms->priv->dpms_capable == FALSE) {
 		gpm_debug ("not DPMS capable");
 		g_set_error (error,
 			     GPM_DPMS_ERROR,
@@ -394,6 +358,16 @@ sync_settings (GpmDpms *dpms,
 		off     = 0;
 	}
 
+	if (dpms->priv->dpms_capable == FALSE) {
+		gpm_debug ("Display is not DPMS capable");
+		g_set_error (error,
+			     GPM_DPMS_ERROR,
+			     GPM_DPMS_ERROR_GENERAL,
+			     "Display is not DPMS capable");
+
+		return FALSE;
+	}
+
 	/* We always try to keep the DPMS enabled so that
 	   we can use set the mode manually.  We will
 	   use zero values for the timeouts when the
@@ -580,9 +554,9 @@ gpm_dpms_mode_to_string (GpmDpmsMode mode)
 }
 
 gboolean
-gpm_dpms_set_mode (GpmDpms    *dpms,
-		   GpmDpmsMode mode,
-		   GError    **error)
+gpm_dpms_set_mode_enum (GpmDpms    *dpms,
+		        GpmDpmsMode mode,
+		        GError    **error)
 {
 	gboolean ret;
 
@@ -603,9 +577,9 @@ gpm_dpms_set_mode (GpmDpms    *dpms,
 }
 
 gboolean
-gpm_dpms_get_mode (GpmDpms     *dpms,
-		   GpmDpmsMode *mode,
-		   GError     **error)
+gpm_dpms_get_mode_enum (GpmDpms     *dpms,
+		        GpmDpmsMode *mode,
+		        GError     **error)
 {
 	gboolean ret;
 
@@ -813,7 +787,10 @@ gpm_dpms_init (GpmDpms *dpms)
 {
 	dpms->priv = GPM_DPMS_GET_PRIVATE (dpms);
 
-	add_poll_timer (dpms, 500);
+	/* DPMSCapable() can never change for a given display */
+	dpms->priv->dpms_capable = DPMSCapable (GDK_DISPLAY ());
+
+	add_poll_timer (dpms, GPM_DPMS_POLL_TIME);
 }
 
 static void
