@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2005-2006 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -83,7 +83,7 @@ void		 gpm_info_event_log			(GpmInfo	*info,
 							 GpmGraphWidgetEvent	 event,
 							 const gchar	*desc);
 
-gboolean	 gpm_statistics_get_types		(GpmInfo	*info,
+gboolean	 gpm_statistics_get_data_types		(GpmInfo	*info,
 							 gchar		***types,
 							 GError		**error);
 gboolean	 gpm_statistics_get_event_log		(GpmInfo	*info,
@@ -95,11 +95,15 @@ gboolean	 gpm_statistics_get_data		(GpmInfo	*info,
 							 const gchar	*type,
 							 GPtrArray	**array,
 							 GError		**error);
-gboolean	 gpm_statistics_get_axis_type		(GpmInfo	*info,
+gboolean	 gpm_statistics_get_axis_types		(GpmInfo	*info,
 							 gchar		*type,
 							 gchar		**axis_type_x,
 							 gchar		**axis_type_y,
 							 GError		**error);
+void		 gpm_info_explain_reason		(GpmInfo	*info,
+							 GpmGraphWidgetEvent event,
+							 const gchar	*pre,
+							 const gchar	*post);
 
 G_END_DECLS
 
